==> aws-java-sdk-api-gateway-1.10.57-sources.jar: com/amazonaws/services/apigateway/model/transform/DeleteAuthorizerRequestMarshaller.java <==
/*
 * Copyright 2010-2016 Amazon.com, Inc. or its affiliates. All Rights
 * Reserved.
 *
 * Licensed under the Apache License, Version 2.0 (the "License").
 * You may not use this file except in compliance with the License.
 * A copy of the License is located at
 *
 *  http://aws.amazon.com/apache2.0
 *
 * or in the "license" file accompanying this file. This file is distributed
 * on an "AS IS" BASIS, WITHOUT WARRANTIES OR CONDITIONS OF ANY KIND, either
 * express or implied. See the License for the specific language governing
 * permissions and limitations under the License.
 */

package com.amazonaws.services.apigateway.model.transform;

import static com.amazonaws.util.StringUtils.UTF8;
import static com.amazonaws.util.StringUtils.COMMA_SEPARATOR;
import java.io.ByteArrayInputStream;
import java.io.ByteArrayOutputStream;
import java.io.OutputStreamWriter;
import java.io.StringWriter;
import java.io.Writer;
import java.util.Collections;
import java.util.HashMap;
import java.util.Map;
import java.util.List;
import java.util.regex.Pattern;

import com.amazonaws.AmazonClientException;
import com.amazonaws.Request;
import com.amazonaws.DefaultRequest;
import com.amazonaws.http.HttpMethodName;
import com.amazonaws.services.apigateway.model.*;
import com.amazonaws.transform.Marshaller;
import com.amazonaws.util.BinaryUtils;
import com.amazonaws.util.StringUtils;
import com.amazonaws.util.StringInputStream;
import com.amazonaws.util.json.*;

/**
 * DeleteAuthorizerRequest Marshaller
 */
public class DeleteAuthorizerRequestMarshaller implements
        Marshaller<Request<DeleteAuthorizerRequest>, DeleteAuthorizerRequest> {

    private static final String DEFAULT_CONTENT_TYPE = "";

    public Request<DeleteAuthorizerRequest> marshall(
            DeleteAuthorizerRequest deleteAuthorizerRequest) {

        if (deleteAuthorizerRequest == null) {
            throw new AmazonClientException(
                    "Invalid argument passed to marshall(...)");
        }

        Request<DeleteAuthorizerRequest> request = new DefaultRequest<DeleteAuthorizerRequest>(
                deleteAuthorizerRequest, "AmazonApiGateway");

        request.setHttpMethod(HttpMethodName.DELETE);

        String uriResourcePath = "/restapis/{restapi_id}/authorizers/{authorizer_id}";

        uriResourcePath = uriResourcePath.replace(
                "{restapi_id}",
                (deleteAuthorizerRequest.getRestApiId() == null) ? ""
                        : StringUtils.fromString(deleteAuthorizerRequest
                                .getRestApiId()));
        uriResourcePath = uriResourcePath.replace(
                "{authorizer_id}",
                (deleteAuthorizerRequest.getAuthorizerId() == null) ? ""
                        : StringUtils.fromString(deleteAuthorizerRequest
                                .getAuthorizerId()));
        request.setResourcePath(uriResourcePath);

        request.setContent(new ByteArrayInputStream(new byte[0]));
        if (!request.getHeaders().containsKey("Content-Type")) {
            request.addHeader("Content-Type", DEFAULT_CONTENT_TYPE);
        }

        return request;
    }

}

==> aws-java-sdk-api-gateway-1.10.75.2-sources.jar: com/amazonaws/services/apigateway/model/transform/DeleteAuthorizerRequestMarshaller.java <==
/*
 * Copyright 2010-2016 Amazon.com, Inc. or its affiliates. All Rights
 * Reserved.
 *
 * Licensed under the Apache License, Version 2.0 (the "License").
 * You may not use this file except in compliance with the License.
 * A copy of the License is located at
 *
 *  http://aws.amazon.com/apache2.0
 *
 * or in the "license" file accompanying this file. This file is distributed
 * on an "AS IS" BASIS, WITHOUT WARRANTIES OR CONDITIONS OF ANY KIND, either
 * express or implied. See the License for the specific language governing
 * permissions and limitations under the License.
 */

package com.amazonaws.services.apigateway.model.transform;

import static com.amazonaws.util.StringUtils.UTF8;
import static com.amazonaws.util.StringUtils.COMMA_SEPARATOR;
import java.io.ByteArrayInputStream;
import java.io.ByteArrayOutputStream;
import java.io.OutputStreamWriter;
import java.io.StringWriter;
import java.io.Writer;
import java.util.Collections;
import java.util.HashMap;
import java.util.Map;
import java.util.List;
import java.util.regex.Pattern;

import com.amazonaws.AmazonClientException;
import com.amazonaws.Request;
import com.amazonaws.DefaultRequest;
import com.amazonaws.http.HttpMethodName;
import com.amazonaws.services.apigateway.model.*;
import com.amazonaws.transform.Marshaller;
import com.amazonaws.util.BinaryUtils;
import com.amazonaws.util.StringUtils;
import com.amazonaws.util.IdempotentUtils;
import com.amazonaws.util.StringInputStream;
import com.amazonaws.util.json.*;

/**
 * DeleteAuthorizerRequest Marshaller
 */
public class DeleteAuthorizerRequestMarshaller implements
        Marshaller<Request<DeleteAuthorizerRequest>, DeleteAuthorizerRequest> {

    private static final String DEFAULT_CONTENT_TYPE = "";

    public Request<DeleteAuthorizerRequest> marshall(
            DeleteAuthorizerRequest deleteAuthorizerRequest) {

        if (deleteAuthorizerRequest == null) {
            throw new AmazonClientException(
                    "Invalid argument passed to marshall(...)");
        }

        Request<DeleteAuthorizerRequest> request = new DefaultRequest<DeleteAuthorizerRequest>(
                deleteAuthorizerRequest, "AmazonApiGateway");

        request.setHttpMethod(HttpMethodName.DELETE);

        String uriResourcePath = "/restapis/{restapi_id}/authorizers/{authorizer_id}";

        uriResourcePath = uriResourcePath.replace(
                "{restapi_id}",
                (deleteAuthorizerRequest.getRestApiId() != null) ? StringUtils
                        .fromString(deleteAuthorizerRequest.getRestApiId())
                        : "");
        uriResourcePath = uriResourcePath
                .replace(
                        "{authorizer_id}",
                        (deleteAuthorizerRequest.getAuthorizerId() != null) ? StringUtils
                                .fromString(deleteAuthorizerRequest
                                        .getAuthorizerId()) : "");
        request.setResourcePath(uriResourcePath);

        request.setContent(new ByteArrayInputStream(new byte[0]));
        if (!request.getHeaders().containsKey("Content-Type")) {
            request.addHeader("Content-Type", DEFAULT_CONTENT_TYPE);
        }

        return request;
    }

}
